# Table of Contents

- [business-context-modeling-guidelines](<./business-context-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Business Context Modeling Guidelines](<./Business-Context-Modeling-Guidelines.md>)
  - [Definition](<./Business-Context-Modeling-Guidelines/Definition.md>)
  - [Description](<./Business-Context-Modeling-Guidelines/Description.md>)
  - [Business Context Fact Sheet Subtypes](<./Business-Context-Modeling-Guidelines/Business-Context-Fact-Sheet-Subtypes.md>)
  - [Guidelines and Best Practices](<./Business-Context-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [Example 1: Product Architecture](<./Business-Context-Modeling-Guidelines/Example-1-Product-Architecture.md>)
  - [Example 2: How to Model Business Architecture with Value Streams and Processes (Manufacturing Company)](<./Business-Context-Modeling-Guidelines/Example-2-How-to-Model-Business-Architecture-with-Value-Streams-and-Processes-Manufacturing-Company.md>)
  - [Example 3: How to Model Business Architecture with Customer Journey and Business Products (Digital Bank)](<./Business-Context-Modeling-Guidelines/Example-3-How-to-Model-Business-Architecture-with-Customer-Journey-and-Business-Products-Digital-Bank.md>)
  - [Antipatterns](<./Business-Context-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Business-Context-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from Business Context Fact Sheet](<./Business-Context-Modeling-Guidelines/Insights-from-Business-Context-Fact-Sheet.md>)
  - [Related Information](<./Business-Context-Modeling-Guidelines/Related-Information.md>)
